@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::ResultSummary;
 # ABSTRACT: Details about the result of running a statement
-$Neo4j::Driver::ResultSummary::VERSION = '0.25';
+$Neo4j::Driver::ResultSummary::VERSION = '0.26';
 
 use Carp qw(croak);
 
@@ -46,8 +46,8 @@ sub counters {
 sub notifications {
 	my ($self) = @_;
 	
-	return $self->{notifications} ? @{$self->{notifications}} : () if wantarray;
-	return $self->{notifications};
+	$self->{notifications} //= [];
+	return @{ $self->{notifications} };
 }
 
 
@@ -89,7 +89,7 @@ Neo4j::Driver::ResultSummary - Details about the result of running a statement
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -133,7 +133,8 @@ statistics counts for operations the statement triggered.
 =head2 notifications
 
  use Data::Dumper;
- print Dumper $summary->notifications;
+ @notifications = $summary->notifications;
+ print Dumper @notifications;
 
 A list of notifications that might arise when executing the
 statement. Notifications can be warnings about problematic statements
@@ -141,8 +142,7 @@ or other valuable information that can be presented in a client.
 Unlike failures or errors, notifications do not affect the execution
 of a statement.
 
-At time of this writing, notifications are not supported on a Bolt
-connection for this driver.
+This driver only supports notifications over HTTP.
 
 =head2 plan
 
@@ -152,8 +152,7 @@ connection for this driver.
 This describes how the database will execute your statement.
 Available if this is the summary of a Cypher C<EXPLAIN> statement.
 
-At time of this writing, execution plans are not supported on a Bolt
-connection for this driver.
+This driver only supports execution plans over HTTP.
 
 =head2 server
 
@@ -179,10 +178,13 @@ these features.
 
 =head2 Calling in scalar context
 
- $notifications = $summary->notifications;  # arrayref
+ $count = $summary->notifications;
 
-The C<notifications()> method returns an array reference if called in
-scalar context, or C<undef> if there are no notifications.
+The C<notifications()> method returns the number of notifications
+if called in scalar context.
+
+Until version 0.25, it returned an array reference instead,
+or C<undef> if there were no notifications.
 
 =head1 SEE ALSO
 
@@ -195,7 +197,7 @@ L<Neo4j::Driver::B<SummaryCounters>>
 
 =item * Equivalent documentation for the official Neo4j drivers:
 L<ResultSummary (Java)|https://neo4j.com/docs/api/java-driver/current/index.html?org/neo4j/driver/summary/ResultSummary.html>,
-L<ResultSummary (JavaScript)|https://neo4j.com/docs/api/javascript-driver/current/class/src/result-summary.js~ResultSummary.html>,
+L<ResultSummary (JavaScript)|https://neo4j.com/docs/api/javascript-driver/4.3/class/lib6/result-summary.js~ResultSummary.html>,
 L<IResultSummary (.NET)|https://neo4j.com/docs/api/dotnet-driver/4.0/html/17958e2b-d923-ab62-bb96-697556493c2e.htm>
 
 =back
